pub struct SmartWallet {
pub base: Pubkey,
pub bump: u8,
pub threshold: u64,
pub minimum_delay: i64,
pub grace_period: i64,
pub owner_set_seqno: u32,
pub num_transactions: u64,
pub owners: Vec<Pubkey>,
pub reserved: [u64; 16],
}Expand description
A SmartWallet is a multisig wallet with Timelock capabilities.
Fields
base: PubkeyBase used to derive.
bump: u8Bump seed for deriving PDA seeds.
threshold: u64Minimum number of owner approvals needed to sign a Transaction.
minimum_delay: i64Minimum delay between approval and execution, in seconds.
grace_period: i64Time after the ETA until a Transaction expires.
owner_set_seqno: u32Sequence of the ownership set.
This may be used to see if the owners on the multisig have changed since the last time the owners were checked. This is used on Transaction approval to ensure that owners cannot approve old transactions.
num_transactions: u64Total number of Transactions on this SmartWallet.
owners: Vec<Pubkey>Owners of the SmartWallet.
reserved: [u64; 16]Extra space for program upgrades.
Implementations
Sourceimpl SmartWallet
impl SmartWallet
Sourcepub fn space(max_owners: u8) -> usize
pub fn space(max_owners: u8) -> usize
Computes the space a SmartWallet uses.
Sourcepub fn owner_index_opt(&self, key: Pubkey) -> Option<usize>
pub fn owner_index_opt(&self, key: Pubkey) -> Option<usize>
Gets the index of the key in the owners Vec, or None
Sourcepub fn try_owner_index(&self, key: Pubkey) -> Result<usize>
pub fn try_owner_index(&self, key: Pubkey) -> Result<usize>
Gets the index of the key in the owners Vec, or error